@@ -11,7 +11,8 @@
 #include "scan.h"
 
 #include <QList>
-#include <QWidget>
+
+#include <kio_version.h>
 
 namespace Filelight
 {
@@ -23,7 +24,7 @@ struct Store {
     /// location of the folder
     const QUrl url;
     /// the folder on which we are operating
-    Folder *folder;
+    std::shared_ptr<Folder> folder;
     /// so we can reference the parent store
     const std::shared_ptr<Store> parent = nullptr;
     /// directories in this folder that need to be scanned before we can propagate()
@@ -31,7 +32,7 @@ struct Store {
 
     Store(const QUrl &url_, const QString &name, const std::shared_ptr<Store> &parentStore)
         : url(url_)
-        , folder(new Folder((name + QLatin1Char('/')).toUtf8().constData()))
+        , folder(std::make_shared<Folder>((name + QLatin1Char('/')).toUtf8().constData()))
         , parent(parentStore)
     {
     }
@@ -63,7 +64,11 @@ RemoteLister::RemoteLister(const QUrl &url, ScanManager *parent)
     , m_store(m_root)
     , m_manager(parent)
 {
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
     setShowingDotFiles(true); // Stupid KDirLister API function names
+#else
+    setShowHiddenFiles(true);
+#endif
 
     // Use SIGNAL(result(KIO::Job*)) instead and then use Job::error()
     connect(this, static_cast<void (KCoreDirLister::*)()>(&KCoreDirLister::completed), this, &RemoteLister::onCompleted);
